Struct DataCatalogConfig
pub struct DataCatalogConfig { /* private fields */ }Expand description
Configuration for a catalog available to request-time historical data loading.
Implementations
impl DataCatalogConfig
impl DataCatalogConfig
pub fn builder() -> DataCatalogConfigBuilder
pub fn builder() -> DataCatalogConfigBuilder
Create an instance of DataCatalogConfig using the builder syntax
impl DataCatalogConfig
impl DataCatalogConfig
pub fn new(
path: String,
fs_protocol: Option<String>,
catalog_backend: Option<CatalogBackendType>,
) -> DataCatalogConfig
pub fn new( path: String, fs_protocol: Option<String>, catalog_backend: Option<CatalogBackendType>, ) -> DataCatalogConfig
Creates a new DataCatalogConfig instance.
pub fn with_storage_options(
self,
options: Option<AHashMap<String, String>>,
) -> DataCatalogConfig
pub fn with_storage_options( self, options: Option<AHashMap<String, String>>, ) -> DataCatalogConfig
Sets native object-store connection options.
pub fn fs_rust_storage_options(&self) -> Option<&AHashMap<String, String>>
pub fn fs_rust_storage_options(&self) -> Option<&AHashMap<String, String>>
Returns native object-store options.
pub fn create_catalog(&self) -> Result<Box<dyn Catalog>, Error>
pub fn create_catalog(&self) -> Result<Box<dyn Catalog>, Error>
Creates the configured catalog through the built-in factory registry.
Errors
Returns an error if the backend is unavailable or its connection cannot be opened.
pub fn with_name(self, name: Option<String>) -> DataCatalogConfig
pub fn with_name(self, name: Option<String>) -> DataCatalogConfig
Returns a copy with catalog registration name set.
pub fn with_params(self, params: Option<Params>) -> DataCatalogConfig
pub fn with_params(self, params: Option<Params>) -> DataCatalogConfig
Returns a copy with backend-specific catalog parameters set.
pub const fn with_read_only(self, read_only: bool) -> DataCatalogConfig
pub const fn with_read_only(self, read_only: bool) -> DataCatalogConfig
Returns a copy with read-only response write-back behavior set.
pub fn fs_protocol(&self) -> &str
pub fn fs_protocol(&self) -> &str
Returns the fsspec file system protocol for the data catalog.
pub const fn catalog_backend(&self) -> &CatalogBackendType
pub const fn catalog_backend(&self) -> &CatalogBackendType
Returns the catalog backend implementation to use.